<?php
/**
 * A script for showing a breadcrumb menu within template files.
 * Use the template tag breadcrumb_trail() to get it to display.
 * Two filter hooks are available for developers to change the
 * output: breadcrumb_trail_args and breadcrumb_trail.
 *
 * @copyright 2008 - 2009
 * @version 0.1.1
 * @author Justin Tadlock
 * @link http://justintadlock.com/archives/2009/04/05/breadcrumb-trail-wordpress-plugin
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Localized to match the Pico theme
 * _e('Text', 'pico')
 * __('Text', 'pico')
 *
 * @package BreadcrumbTrail
 */

/**
 * Shows a breadcrumb for all types of pages.  Themes and 
 * plugins can filter $args or input directly.  Allow filtering of 
 * only the $args using get_the_breadcrumb_args.
 *
 * @since 0.1
 * @global $post The current post's DB object.
 * @param array $args Mixed arguments for the menu.
 * @return string Output of the breadcrumb menu.
 */
function breadcrumb_trail( $args = array() ) {
	global $post, $wp_query;

	/* Set up the default arguments for the breadcrumb. */
	$defaults = array(
		'separator' => '/',
		'before' => '<span class="breadcrumb-title">' . __('Browse:', 'pico') . '</span>',
		'after' => false,
		'front_page' => true,
		'show_home' => __('Home', 'pico'),
		'single_tax' => 'category',
		'format' => 'flat', // Implement later
		'echo' => true,
	);

	/* Apply filters to the arguments. */
	$args = apply_filters( 'breadcrumb_trail_args', $args );

	/* Parse the arguments and extract them for easy variable naming. */
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	/* Put spaces around the separator. */
	$separator = ' ' . $separator . ' ';

	/* If it is the front page and $front_page is false, return no value. */
	if ( is_front_page() && !$front_page )
		return;

	/* Begin the breadcrumb. */
	$breadcrumb = '<div class="breadcrumb breadcrumbs"><div class="breadcrumb-trail">' . $before . ' ';

	/* Display home link. */
	if ( $show_home && !is_home() && !is_front_page() )
		$breadcrumb .= '<a href="' . get_bloginfo( 'url' ) . '" title="' . get_bloginfo( 'name' ) . '" rel="home" class="trail-begin">' . $show_home . '</a>' . $separator;

	/* If it is the home page or front page. */
	if ( ( is_front_page() && $front_page ) || is_home() ) :
		$breadcrumb .= '<span class="trail-end">' . $show_home . '</span>';

	/* If it is a page. */
	elseif ( is_page() ) :
		$parent_id = $post->post_parent;
		while ( $parent_id ) :
			$page = get_page( $parent_id );
			$parents[]  = '<a href="' . get_permalink( $page->ID ) . '" title="' . get_the_title( $page->ID ) . '">' . get_the_title( $page->ID ) . '</a> ' . $separator;
			$parent_id  = $page->post_parent;
		endwhile;
		if ( $parents ) :
			$parents = array_reverse( $parents );
			$breadcrumb .= join( ' ', $parents );
		endif;
		$breadcrumb .= '<span class="trail-end">' . get_the_title() . '</span>';

	/* If is attachment page. */
	elseif ( is_attachment() ) :
		$breadcrumb .= '<a href="' . get_permalink( $post->post_parent ) . '" title="' . get_the_title( $post->post_parent ) . '">' . get_the_title( $post->post_parent ) . '</a>';
		$breadcrumb .= $separator . '<span class="trail-end">' . get_the_title() . '</span>';

	/* Single posts. */
	elseif ( is_single() ) :
		if ( $single_tax && $terms = get_the_term_list( $post->ID, $single_tax, '', ', ', '' ) ) :
			$breadcrumb .= $terms . $separator;
		endif;
		$breadcrumb .= '<span class="trail-end">' . single_post_title( false, false ) . '</span>';

	/* Taxonomy (tags, categories, etc.) archives. */
	elseif ( is_tax() || is_category() || is_tag() ) :
		$term = $wp_query->get_queried_object();

		if ( is_category() && $term->parent ) :
			$parents = get_category_parents( $term->parent, true, $separator, false );
			if ( $parents ) :
				$breadcrumb .= $parents;
			endif;
		endif;

		$breadcrumb .= '<span class="trail-end">' . $term->name . '</span>';

	/* Author archives. */
	elseif ( is_author() ) :
		$breadcrumb .= '<span class="trail-end">' . get_the_author_meta( 'display_name', get_query_var( 'author' ) ) . '</span>';

	/* Search results. */
	elseif ( is_search() ) :
		$breadcrumb .= '<span class="trail-end">' . sprintf( __('Search results for &quot;%1$s&quot;', 'pico'), esc_attr( get_search_query() ) ) . '</span>';

	/* Minutely and hourly archives. */
	elseif ( get_query_var( 'minute' ) && get_query_var( 'hour' ) ) :
		$breadcrumb .= '<span class="trail-end">' . get_the_time( __('g:i a', 'pico') ) . '</span>';

	/* Minutely archives. */
	elseif ( get_query_var( 'minute' ) ) :
		$breadcrumb .= '<span class="trail-end">' . sprintf( __('Minute %1$s', 'pico'), get_the_time( __('i', 'pico') ) ) . '</span>';

	/* Hourly archives. */
	elseif ( get_query_var( 'hour' ) ) :
		$breadcrumb .= '<span class="trail-end">' . get_the_time( __('g a', 'pico') ) . '</span>';

	/* Daily archives. */
	elseif ( is_day() ) :
		$breadcrumb .= '<a href="' . get_year_link( get_the_time( __('Y', 'pico') ) ) . '" title="' . get_the_time( __('Y', 'pico') ) . '">' . get_the_time( __('Y', 'pico') ) . '</a>' . $separator;
		$breadcrumb .= '<a href="' . get_month_link( get_the_time( __('Y', 'pico') ), get_the_time( __('m', 'pico') ) ) . '" title="' . get_the_time( __('F', 'pico') ) . '">' . get_the_time( __('F', 'pico') ) . '</a>' . $separator;
		$breadcrumb .= '<span class="trail-end">' . get_the_time( __('j', 'pico') ) . '</span>';

	/* Weekly archives. */
	elseif ( get_query_var( 'w' ) ) :
		$breadcrumb .= '<a href="' . get_year_link( get_the_time( __('Y', 'pico') ) ) . '" title="' . get_the_time( __('Y', 'pico') ) . '">' . get_the_time( __('Y', 'pico') ) . '</a>' . $separator;
		$breadcrumb .= '<span class="trail-end">' . sprintf( __('Week %1$s', 'pico' ), get_the_time( __('W', 'pico') ) ) . '</span>';

	/* Monthly archives. */
	elseif ( is_month() ) :
		$breadcrumb .= '<a href="' . get_year_link( get_the_time( __('Y', 'pico') ) ) . '" title="' . get_the_time( __('Y', 'pico') ) . '">' . get_the_time( __('Y', 'pico') ) . '</a>' . $separator;
		$breadcrumb .= '<span class="trail-end">' . get_the_time( __('F', 'pico') ) . '</span>';

	/* Yearly archives. */
	elseif ( is_year() ) :
		$breadcrumb .= '<span class="trail-end">' . get_the_time( __('Y', 'pico') ) . '</span>';

	/* 404 error pages. */
	elseif ( is_404() ) :
		$breadcrumb .= '<span class="trail-end">' . __('404 Not Found', 'pico') . '</span>';

	/* Everything else. */
	else :
		$breadcrumb .= '<span class="trail-end">' . wp_title( false, false, false ) . '</span>';

	endif;

	/* End the breadcrumb. */
	$breadcrumb .= $after . '</div></div>';

	/* Output the breadcrumb. */
	if ( $echo )
		echo apply_filters( 'breadcrumb_trail', $breadcrumb );
	else
		return apply_filters( 'breadcrumb_trail', $breadcrumb );
}

?>